# Rubik Vault

Welcome to Rubik Vault, your place to explore and collect Rubik cube images!

## Description

Rubik Vault is a simple application created by Michael100 that allows you to discover a variety of Rubik cube images. Register, log in, and select your favourite cubes to store in your own personal collection.

## Features

- Explore Rubik's Cube images of various types and styles.
- Register and login to access advanced features.
- Create your personal collection by selecting your favourite cubes.
- View your collection in a unique gallery.

## Installation

1. Run the .exe file on your computer.
2. Open the .exe location and create a file called users.txt.

## Login and User Registration

- Click "Login" to access your existing account.
- If you are new, select "Register" to create an account.

## Storing Selected Cubes

- After logging in, select your favourite cubes to add to your collection.
- Your selected cubes will be saved and available each time you log in.

## Contributions

If you want to contribute to the project, feel free to make a fork and send pull requests!